package com.jqtx.windows.command;


import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson.JSON;
import com.jqtx.infrastructure.oss.starter.config.OssUtils;
import com.jqtx.infrastructure.oss.starter.properties.OssProperties;
import com.jqtx.infrastructure.util.LoanMobileAESUtil;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.infrastructure.feign.IClientFeignService;
import com.jqtx.windows.infrastructure.feign.IWakandaFeignService;
import com.jqtx.windows.infrastructure.feign.enums.ProductNameEnum;
import com.jqtx.windows.infrastructure.feign.model.client.ClientFeignModel;
import com.jqtx.windows.infrastructure.feign.model.wakanda.BasicInfoModel;
import com.jqtx.windows.infrastructure.feign.model.wakanda.ClientInfoModel;
import com.jqtx.windows.infrastructure.feign.model.wakanda.CreditInformationModel;
import com.jqtx.windows.infrastructure.feign.model.wakanda.IdentifyInfoModel;
import com.jqtx.windows.web.request.CreditSubmitRequest;
import com.jqtx.windows.web.response.JsonResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

@Service
public class CreditSubmitCommand extends AbstractCommand {


    @Autowired
    private CreditComponent creditComponent;

    @Autowired
    private OssUtils ossUtils;

    @Autowired
    private OssProperties ossProperties;

    @Autowired
    private IClientFeignService iClientFeignService;

    @Autowired
    private IWakandaFeignService iWakandaFeignService;

    @Override
    public JsonResult execute() {
        String requestBody = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        CreditSubmitRequest request = JSON.parseObject(requestBody,CreditSubmitRequest.class);
        CreditModel order = creditComponent.getByOrderNo(request.getOrderNo());
        if(ObjectUtil.isNotNull(order)){
            return JsonResult.success();
        }
        CreditModel insert = this.convert(request);
        StringBuilder filePath = new StringBuilder();
        filePath.append("CREDIT_DATA").append("/").append(DateUtil.format(new Date(),"yyyyMMdd")).append("/").append(request.getOrderNo()).append(".json");
        insert.setCreditDetailUrl(filePath.toString());
        ClientInfoModel infoModel = this.convertCredit(request,insert);
        JsonResult result = iWakandaFeignService.clientCredit(infoModel);
        result.resultCheck();
        creditComponent.insert(insert);
        return JsonResult.success();
    }



    private ClientInfoModel convertCredit(CreditSubmitRequest request,CreditModel model){
        ClientInfoModel clientInfoModel =new ClientInfoModel();
        CreditInformationModel infoModel = request.getCreditData();
        clientInfoModel.setCertNo(infoModel.getBasicInfo().getIdCard());
        clientInfoModel.setClientName(infoModel.getBasicInfo().getName());
        clientInfoModel.setClientNo(model.getClientNo());
        clientInfoModel.setOrderNo(request.getOrderNo());
        clientInfoModel.setMobileEncrypt(LoanMobileAESUtil.encrypt(model.getClientCell()));
        clientInfoModel.setProductName("ZN_DAI");
        clientInfoModel.setCreditPath(model.getCreditDetailUrl());
        clientInfoModel.setBizType(ProductNameEnum.getByCode(clientInfoModel.getProductName()).getBiz());
        return clientInfoModel;
    }

    private CreditModel convert(CreditSubmitRequest request){
        CreditModel model =new CreditModel();
        CreditInformationModel infoModel = request.getCreditData();
        IdentifyInfoModel idModel = infoModel.getIdentifyInfo();
        BasicInfoModel basicModel = infoModel.getBasicInfo();


        StringBuilder frontUrl = new StringBuilder();
        frontUrl.append("USERCREDIT").append("/").append(DateUtil.format(new Date(),"yyyyMMdd")).append("/front_").append(request.getOrderNo()).append(".jpg");
        HttpResponse frontResponse = HttpRequest.get(idModel.getFrontFile()).setConnectionTimeout(5000).execute();
        ossUtils.ossUpload(frontUrl.toString(), frontResponse.bodyStream());
        idModel.setFrontFile(ossProperties.getPrivateDomain() + frontUrl);

        StringBuilder backUrl = new StringBuilder();
        frontUrl.append("USERCREDIT").append("/").append(DateUtil.format(new Date(),"yyyyMMdd")).append("/back_").append(request.getOrderNo()).append(".jpg");
        HttpResponse backResponse = HttpRequest.get(idModel.getBackFile()).setConnectionTimeout(5000).execute();
        ossUtils.ossUpload(backUrl.toString(), backResponse.bodyStream());
        idModel.setFrontFile(ossProperties.getPrivateDomain() + backUrl);

        StringBuilder bestUrl = new StringBuilder();
        frontUrl.append("USERCREDIT").append("/").append(DateUtil.format(new Date(),"yyyyMMdd")).append("/nature_").append(request.getOrderNo()).append(".jpg");
        HttpResponse natureResponse = HttpRequest.get(idModel.getNatureFile()).setConnectionTimeout(5000).execute();
        ossUtils.ossUpload(bestUrl.toString(), natureResponse.bodyStream());
        idModel.setNatureFile(ossProperties.getPrivateDomain() + bestUrl);

        infoModel.setIdentifyInfo(idModel);

        infoModel.setContinuedLoan(false);
        ClientFeignModel clientFeignModel = new ClientFeignModel(infoModel.getBasicInfo().getIdCard(), infoModel.getBasicInfo().getName());
        JsonResult<String> clientResult = iClientFeignService.getClientNo(clientFeignModel);
        if (!clientResult.isSuccess()) {
            throw new BizException(ExceptionCodeEnum.SYSTEM_REMOTE_ERROR);
        }
        model.setClientNo(clientResult.getResult());
        ossUtils.upStringObject(model.getCreditDetailUrl(), JSON.toJSONString(infoModel));
        model.setClientCell(basicModel.getPhone());
        model.setCertNo(basicModel.getIdCard());
        model.setClientName(basicModel.getName());
        return model;
    }
}
