package com.jqtx.windows.command;

import cn.hutool.core.bean.BeanUtil;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.web.response.JsonResult;
import com.jqtx.windows.web.response.LoanSubmitResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * 提现审核结果查询
 */
@Service
@Slf4j
public class LoanStatusCommand extends AbstractCommand {

    @Autowired
    private LoanComponent loanComponent;

    @Override
    public JsonResult execute() {
        String request = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        LoanSubmitResponse loanSubmitResponse = BeanUtil.toBean(request, LoanSubmitResponse.class);
        LoanModel byLoanNo = loanComponent.getByLoanNo(loanSubmitResponse.getLoanNo());
        if (Objects.isNull(byLoanNo)) {
            throw new BizException(ExceptionCodeEnum.BIZ_CREDIT_NOT_FOUND_ERROR);
        }
        if (StringUtils.isEmpty(byLoanNo.getLoanCreditResult())) {
            throw new BizException(ExceptionCodeEnum.RESULT_NOT_FOUND_ERROR);
        }
        return JsonResult.success(byLoanNo.getLoanCreditResult());
    }
}
